Skip to contents

This class inherits from GaussianEmpiricalBayesPP and implements the Gravestock's EBPP method.

Format

R6Class object.

Super classes

Model -> GaussianConjugate -> GaussianStaticBorrowing -> GaussianEmpiricalBayesPP -> GaussianGravestockEBPP

Public fields

method

Method name

Methods

Inherited methods


GaussianGravestockEBPP$new()

Initialize the GaussianGravestockEBPP object.

Usage

GaussianGravestockEBPP$new(prior, null_space, theta_0)

Arguments

prior

The prior object.

null_space

Side of the null hypothesis space

theta_0

Boundary of the null hypothesis space

Returns

NULL


GaussianGravestockEBPP$power_parameter_estimation()

Estimate the power parameter using the Gravestock's EBPP method.

Usage

GaussianGravestockEBPP$power_parameter_estimation(target_data)

Arguments

target_data

The target data.

source_treatment_effect_estimate

Treatment effect estimate in the source study

target_treatment_effect_estimate

Treatment effect estimate in the target study

Returns

The estimated power parameter.


GaussianGravestockEBPP$vectorised_power_parameter()

Estimate the power parameter for every replicate at once.

Same closed form as power_parameter_estimation(), evaluated on vectors.

Usage

GaussianGravestockEBPP$vectorised_power_parameter(target_data, samples)

Arguments

target_data

The target data.

samples

Data frame of generated replicates.

Returns

A vector of power parameters.


GaussianGravestockEBPP$clone()

The objects of this class are cloneable with this method.

Usage

GaussianGravestockEBPP$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.