Skip to contents

This class represents a p-value based power prior method. It inherits from the GaussianEmpiricalBayesPP class.

Super classes

Model -> GaussianConjugate -> GaussianStaticBorrowing -> GaussianEmpiricalBayesPP -> GaussianPValueBasedPP

Public fields

shape_parameter

The shape parameter for the method.

method

Method name

Methods

Inherited methods


GaussianPValueBasedPP$new()

Initialize the p_value_based_PP object.

Usage

GaussianPValueBasedPP$new(prior, theta_0, null_space)

Arguments

prior

The prior object.

theta_0

Boundary of the null hypothesis space

null_space

Null space.

Returns

None Test method


GaussianPValueBasedPP$test()

This method performs the test for the given target data.

Usage

GaussianPValueBasedPP$test(
  target_data,
  source_treatment_effect_estimate,
  target_treatment_effect_estimate,
  test_type = "t-test"
)

Arguments

target_data

The target data object.

source_treatment_effect_estimate

The source treatment effect estimate.

target_treatment_effect_estimate

The target treatment effect estimate.

test_type

Type of frequentist test used

Returns

The p-value. Power parameter estimation method


GaussianPValueBasedPP$power_parameter_estimation()

This method estimates the power parameter for the given target data.

Usage

GaussianPValueBasedPP$power_parameter_estimation(target_data)

Arguments

target_data

The target data object.

Returns

The power parameter.


GaussianPValueBasedPP$vectorised_power_parameter()

Estimate the power parameter for every replicate at once.

Reproduces test() followed by power_parameter_estimation(). The two one-sided equivalence tests are the same summary-statistic t-tests that test() runs through BSDA, evaluated on vectors.

Usage

GaussianPValueBasedPP$vectorised_power_parameter(target_data, samples)

Arguments

target_data

The target data.

samples

Data frame of generated replicates.

Returns

A vector of power parameters.


GaussianPValueBasedPP$clone()

The objects of this class are cloneable with this method.

Usage

GaussianPValueBasedPP$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.