Skip to contents

This class represents the source data used for Bayesian borrowing. It processes the source data to compute necessary statistics for various endpoints.

Super class

ObservedSourceData -> SourceData

Methods

Inherited methods


SourceData$new()

Initialize the SourceData object

Usage

SourceData$new(case_study_config, source_denominator = NA)

Arguments

case_study_config

list: A configuration list containing details of the case study.

source_denominator

numeric: An optional denominator for computing control rates.

Returns

A new SourceData object.


SourceData$clone()

The objects of this class are cloneable with this method.

Usage

SourceData$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.