Plot methods operating characteristics
Source:R/plot_bayesian_operating_characteristics.R
bayesian_ocs_plots.RdThis function generates plots for the operating characteristics of different methods.
R/plot_bayesian_operating_characteristics.R
bayesian_ocs_plots.RdThis function generates plots for the operating characteristics of different methods.