Skip to contents

OCs vs TIE.

Usage

bayesian_operating_characteristics_vs_tie_plots(
  results_bayes_df,
  results_freq_df,
  bayesian_metrics
)

Arguments

results_bayes_df

The Bayesian results data frame.

results_freq_df

The frequentist results data frame, from which the type I error rates are read.

bayesian_metrics

List of Bayesian metrics, as defined by sourcing metrics_config.R.

Value

None

Examples

NA
#> [1] NA