Skip to contents

T(i, s - i) as an N x N matrix indexed by the source control rate i and the source treatment rate s, zero where the risk difference s - i is not among those the target data reach.

Usage

binomial_power_prior_bilinear(terms)

Arguments

terms

Output of binomial_power_prior_target_terms().

Value

An N x N matrix.