Prior kernels of the binomial robust mixture prior with a given weight
Source:R/binomial_rmp.R
binomial_rmp_kernels.RdPrior kernels of the binomial robust mixture prior with a given weight
Arguments
- components
Output of
binomial_rmp_components().- weight
Prior weight of the informative component.
Value
A list as binomial_npp_posterior() reads it, whose
prior_weight moment gives the posterior weight of the informative
component.