Compute the source denominator range for a given source data, simulation configuration, and case study configuration.
Source:R/simulation_scenarios.R
compute_source_denominator_range.RdCompute the source denominator range for a given source data, simulation configuration, and case study configuration.