Plot the posterior parameters
Source:R/plot_empirical_bayes_hyperparameters_vs_scenario.R
empirical_bayes_parameters_plots.RdPlot the hyperparameters updated using empirical Bayes as a function of drift, for each scenario.
R/plot_empirical_bayes_hyperparameters_vs_scenario.R
empirical_bayes_parameters_plots.RdPlot the hyperparameters updated using empirical Bayes as a function of drift, for each scenario.