Plot methods comparison
Source:R/plot_methods_comparison_forestplot.R
forest_plot_methods_comparison.RdThis function plots the comparison of methods based on the provided results metrics dataframe.
R/plot_methods_comparison_forestplot.R
forest_plot_methods_comparison.RdThis function plots the comparison of methods based on the provided results metrics dataframe.