Skip to contents

This function generates a forest plot based on the provided results dataframe, selected case study, and selected target sample size per arm.

Usage

forest_plot_sweet_spot(results_freq_df, x_metric)

Arguments

results_freq_df

The results dataframe.

x_metric

Metric on the x-axis

Value

None