Skip to contents

Format a case study configuration as a printable table

Usage

format_case_study_config(case_study_config)

Arguments

case_study_config

Case study configuration list.

Value

A data frame with one row per configuration field, suitable for printing (used by the data-generation vignettes to describe a case study).