Skip to contents

This function calculates the moment-based ESS for a Gaussian mixture distribution. It takes a mixture object and an optional prior reference scale as input and returns the ESS.

Usage

gaussian_mix_moment_ess(mix)

Arguments

mix

A mixture object.

Value

The moment-based ESS for the Gaussian mixture.