Skip to contents

This function calculates the precision-based ESS for a Gaussian mixture distribution. It takes a mixture object and an optional prior reference scale as input and returns the ESS.

Usage

gaussian_mix_precision_ess(mix)

Arguments

mix

A mixture object.

Value

The precision-based ESS for the Gaussian mixture.