Inverts the piecewise linear distribution function. Its flat stretches, where the density underflowed to zero, are dropped first, so the inverse is well defined.
Arguments
- posterior
Output of
grid_posterior().- probability
Probabilities.
Inverts the piecewise linear distribution function. Its flat stretches, where the density underflowed to zero, are dropped first, so the inverse is well defined.
Output of grid_posterior().
Probabilities.