Get important drift values for a given source treatment effect and case study configuration.
Source:R/simulation_scenarios.R
important_drift_values.RdGet important drift values for a given source treatment effect and case study configuration.