Interpolate an expensive function of a positive scalar
Source:R/method_empirical_bayes_power_prior.R
log_grid_interpolation.RdEvaluates f at n_nodes points spaced evenly on the log scale
across the range of x, and interpolates linearly in log(x) between them.
Where every x is equal, f is evaluated once.