Skip to contents

Read from the method parameters, with the defaults of calibrate_npp_kl(). Shared by GaussianNPP_KL and BinomialNPP_KL.

Usage

npp_kl_settings(parameters, null_space)

Arguments

parameters

The method parameters.

null_space

The null hypothesis space, which gives the benefit direction when benefit_sign is not configured.

Value

A list of settings.