Plot methods operating characteristics
Source:R/plot_frequentist_operating_characteristics.R
plot_metric_vs_scenario.RdThis function generates plots for the operating characteristics of different methods.
R/plot_frequentist_operating_characteristics.R
plot_metric_vs_scenario.RdThis function generates plots for the operating characteristics of different methods.