Calculate the probability of true positive
Source:R/analysis_bayesian_ocs.R
preposterior_proba_TP_MC.RdThis function calculates the probability of true positive based on the conditional probability of success, design prior samples, theta_0, and null space.
Usage
preposterior_proba_TP_MC(
conditional_proba_success,
design_prior_samples,
theta_0,
null_space
)