Sample aggregate binary data based on the rate and sample size
Source:R/simulation_data.R
sample_aggregate_binary_data.RdThis function samples aggregate binary data based on the rate and sample size.
R/simulation_data.R
sample_aggregate_binary_data.RdThis function samples aggregate binary data based on the rate and sample size.