The KL-calibrated normalized power prior of GaussianNPP_KL
for a binary endpoint: the Beta prior on the power parameter is calibrated
to the design with the criterion of calibrate_npp_kl(), the posterior of
the power parameter under the two hypothetical results being computed from
the binomial marginal likelihood (npp_kl_calibrate_design_binomial()),
and the target data are analysed with the binomial normalized power prior,
BinomialNPP, under that prior. The shape parameters are NULL until
Model$calibrate_for_design() has run.
Super classes
Model -> MCMCModel -> BinomialLatticePrior -> BinomialNPP -> BinomialNPP_KL
Public fields
methodName of the method.
theta_0Boundary of the null hypothesis space.
null_spaceThe null hypothesis space, which gives the benefit direction.
calibrationThe result of
calibrate_npp_kl()for this scenario.calibration_settingsThe criterion settings read from the method parameters.
Methods
Inherited methods
Model$check_data()Model$create()Model$empirical_bayes_update()Model$estimate_bayesian_operating_characteristics()Model$estimate_frequentist_operating_characteristics()Model$hypothesis_space_transformation()Model$inference_cache_scope()Model$plot_pdfs()Model$plot_posterior_pdf()Model$plot_prior_pdf()Model$posterior_beta_mixture()Model$posterior_mean()Model$posterior_moments()Model$posterior_quantile()Model$posterior_to_RBesT()Model$print_model_summary()Model$prior_to_RBesT()Model$simulation_for_given_treatment_effect()Model$test_decision()Model$vectorised_replicate_inference()MCMCModel$check_mcmc_config()MCMCModel$credible_interval()MCMCModel$draw_mcmc_prior()MCMCModel$inference()MCMCModel$posterior_cdf()MCMCModel$posterior_ess()MCMCModel$posterior_median()MCMCModel$posterior_pdf()MCMCModel$prepare_data()MCMCModel$prior_cdf()MCMCModel$prior_pdf()MCMCModel$sample_posterior()MCMCModel$sample_prior()MCMCModel$stan_sampler()MCMCModel$uses_quadrature()BinomialLatticePrior$prior_elir_ess()BinomialLatticePrior$prior_given_control_rate()BinomialLatticePrior$quadrature_posterior()BinomialLatticePrior$quadrature_prior()BinomialLatticePrior$source_counts()BinomialNPP$kernel_key()BinomialNPP$kernels()BinomialNPP$summary_rows()
BinomialNPP_KL$new()
Initialize a BinomialNPP_KL model.
Usage
BinomialNPP_KL$new(prior, theta_0, null_space, mcmc_config)BinomialNPP_KL$calibrate_for_design()
Calibrate the prior on the power parameter to this design,
with the criterion of calibrate_npp_kl() evaluated on the binomial
marginal likelihood; see npp_kl_calibrate_design_binomial().
BinomialNPP_KL$compute_posterior_parameters()
Record the posterior moments of the power parameter and the calibration, which is constant within a scenario.