This class represents a p-value based power prior method. It inherits from the GaussianEmpiricalBayesPP class.
Super classes
Model -> GaussianConjugate -> GaussianStaticBorrowing -> GaussianEmpiricalBayesPP -> GaussianPValueBasedPP
Methods
Inherited methods
Model$calibrate_for_design()Model$check_data()Model$create()Model$estimate_bayesian_operating_characteristics()Model$estimate_frequentist_operating_characteristics()Model$hypothesis_space_transformation()Model$inference_cache_scope()Model$plot_pdfs()Model$plot_posterior_pdf()Model$plot_prior_pdf()Model$posterior_beta_mixture()Model$posterior_ess()Model$posterior_quantile()Model$print_model_summary()Model$prior_elir_ess()Model$simulation_for_given_treatment_effect()Model$test_decision()GaussianConjugate$credible_interval()GaussianConjugate$posterior_cdf()GaussianConjugate$posterior_mean()GaussianConjugate$posterior_median()GaussianConjugate$posterior_moments()GaussianConjugate$posterior_pdf()GaussianConjugate$posterior_to_RBesT()GaussianConjugate$posterior_variance()GaussianConjugate$prior_cdf()GaussianConjugate$prior_to_RBesT()GaussianConjugate$sample_posterior()GaussianConjugate$sample_prior()GaussianConjugate$vectorised_replicate_inference()GaussianStaticBorrowing$summary_rows()GaussianEmpiricalBayesPP$empirical_bayes_update()GaussianEmpiricalBayesPP$inference()GaussianEmpiricalBayesPP$plot_power_parameter_vs_drift()GaussianEmpiricalBayesPP$prior_pdf()GaussianEmpiricalBayesPP$vectorised_posterior_parameters()GaussianEmpiricalBayesPP$vectorised_prior_variance()
GaussianPValueBasedPP$new()
Initialize the p_value_based_PP object.
Usage
GaussianPValueBasedPP$new(prior, theta_0, null_space)GaussianPValueBasedPP$test()
This method performs the test for the given target data.
Usage
GaussianPValueBasedPP$test(
target_data,
source_treatment_effect_estimate,
target_treatment_effect_estimate,
test_type = "t-test"
)GaussianPValueBasedPP$power_parameter_estimation()
This method estimates the power parameter for the given target data.
GaussianPValueBasedPP$vectorised_power_parameter()
Estimate the power parameter for every replicate at once.
Reproduces test() followed by power_parameter_estimation(). The two
one-sided equivalence tests are the same summary-statistic t-tests that
test() runs through BSDA, evaluated on vectors.