Skip to contents

This class represents a model with pooled Gaussian components, inheriting from GaussianStaticBorrowing. The power parameter is set to 1.

Super classes

Model -> GaussianConjugate -> GaussianStaticBorrowing -> GaussianPooling

Public fields

method

Method name

Methods

Inherited methods


GaussianPooling$new()

Usage

GaussianPooling$new(prior)

Arguments

prior

Prior

Returns

A Model object.


GaussianPooling$clone()

The objects of this class are cloneable with this method.

Usage

GaussianPooling$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

NA
#> [1] NA