This class represents the observed source data used for Bayesian borrowing in clinical studies.
Public fields
endpointcharacter. The endpoint of the study. Possible values are "continuous", "binary", "time_to_event", "recurrent_event".
summary_measure_likelihoodcharacter. The distribution of the summary measure. Possible values are "normal", "Binomial".
sample_size_controlnumeric. The sample size in the control arm of the source data.
sample_size_treatmentnumeric. The sample size in the treatment arm of the source data.
treatment_effect_estimatenumeric. The estimated treatment effect in the source data.
standard_errornumeric. The standard error of the treatment effect estimate in the source data.
control_ratenumeric. The rate of success (1s) in the control arm of the source data (for binary endpoint).
treatment_ratenumeric. The rate of success (1s) in the treatment arm of the source data (for binary endpoint).
equivalent_source_sample_size_per_armnumeric. Equivalent sample size per arm.
Methods
ObservedSourceData$new()
Initialize an instance of ObservedSourceData
Usage
ObservedSourceData$new(case_study_config)