This class represents target data for recurrent event analysis. It inherits from the TargetData class.
Public fields
control_rateRate in the control arm of the target study
treatment_rateRate in the treatment arm of the target study
k_treatmentNegative-binomial size parameter in the treatment arm
k_controlNegative-binomial size parameter in the control arm
Methods
Inherited methods
NA$new()
Initialize the RecurrentEventTargetData object
Usage
NA$new(
source_data,
sampling_approximation,
target_sample_size_per_arm,
control_drift = 0,
treatment_drift,
summary_measure_likelihood,
k_treatment = 0.8,
k_control = 0.8
)Arguments
source_dataThe source data used for generating the target data.
sampling_approximationA flag indicating whether to use sampling approximation.
target_sample_size_per_armThe target sample size per arm.
control_driftThe control drift.
treatment_driftThe treatment drift.
summary_measure_likelihoodThe summary measure distribution.
k_treatmentSize parameter for the negative binomial distribution in the treatment arm.
k_controlSize parameter for the negative binomial distribution in the control arm. Generate target data