This class represents the source data used for Bayesian borrowing. It processes the source data to compute necessary statistics for various endpoints.
Super class
ObservedSourceData -> SourceData
Methods
Inherited methods
SourceData$new()
Initialize the SourceData object
Usage
SourceData$new(case_study_config, source_denominator = NA)