A class representing the source posterior design prior for Bayesian borrowing.
Super class
DesignPrior -> SourcePosteriorDesignPrior
Public fields
parametersParameters
summary_measure_likelihoodTreatment effect distribution
n_successes_controlNumber of successes in the control arm
n_successes_treatmentNumber of successes in the treatment arm
n_controlNumber of participants in the control arm
n_treatmentNumber of participants in the treatment arm
Methods
Inherited methods
SourcePosteriorDesignPrior$new()
Initializes a new instance of SourcePosteriorDesignPrior.
Usage
SourcePosteriorDesignPrior$new(
source_data,
case_study_config,
simulation_config,
mcmc_config = NULL
)SourcePosteriorDesignPrior$cdf()
Computes the cumulative distribution function (CDF) of the source posterior design prior.
SourcePosteriorDesignPrior$given_control_rate()
The source posterior given the target control rate
Under a binomial likelihood the source posterior is independent Beta posteriors on the two arms' response rates, so given the control rate the effect is the treatment rate, from its source posterior, less that rate. Otherwise the inherited truncation applies.
SourcePosteriorDesignPrior$pdf()
Computes the cumulative distribution function (PDF) of the source posterior design prior.