A base class for target data objects.
Public fields
endpointThe endpoint of the target data.
treatment_driftThe treatment drift value.
control_driftThe control drift value.
driftThe drift value calculated as the difference between treatment and control drifts.
summary_measure_likelihoodThe distribution of the summary measure.
sample_size_per_armThe target sample size per arm.
sample_size_controlThe target sample size for the control group.
sample_size_treatmentThe target sample size for the treatment group.
treatment_effectThe target treatment effect value.
sampling_approximationThe flag indicating if sampling approximation is used.
standard_deviationThe true sampling standard deviation of the summary measure for one patient per arm, i.e. the data-generating value: the true standard error of the treatment-effect estimate is
standard_deviation / sqrt(sample_size_per_arm). It belongs to the scenario, not to a replicate. A replicate's estimate of it issample$standard_deviation(seesample_aggregate_normal_data()), which is what the analysis methods use; the true value is only used to generate data and for design-stage quantities such as the analytical power and the KL-NPP calibration.sampleThe sample data.
Methods
TargetData$new()
Initializes the target data object.
Usage
TargetData$new(
source_data,
sampling_approximation,
target_sample_size_per_arm,
control_drift = 0,
treatment_drift,
summary_measure_likelihood
)