Averaging a function over these nodes integrates it against the Beta density by the midpoint rule in probability space, which follows the mass of the distribution without any tuning.
Averaging a function over these nodes integrates it against the Beta density by the midpoint rule in probability space, which follows the mass of the distribution without any tuning.