Prior kernels of the binomial commensurate priors
Source:R/binomial_commensurate.R
binomial_commensurate_prior_kernels.RdThe prior of the target control rate and risk difference, integrated over the source risk difference, the power parameter and the commensurability parameter, on the lattice, with the kernels weighted by the commensurability parameter and by the power parameter, and by their squares, for their posterior moments.
Usage
binomial_commensurate_prior_kernels(
source_counts,
tau_rule,
borrows_power_parameter,
tau_moments_exist,
n_lattice = 1000L
)Arguments
- source_counts
List of the four source counts.
- tau_rule
Output of
commensurate_tau_quadrature().- borrows_power_parameter
TRUEfor the commensurate power prior,FALSEfor the commensurate prior (gamma = 1).- tau_moments_exist
Output of
commensurate_tau_moments_exist().- n_lattice
Number of lattice points N.
Value
A list with n_lattice, rates, differences, kernel and
moments, as binomial_npp_posterior() reads them.