Log marginal likelihood of the target data under the binomial power prior
Source:R/binomial_ebpp.R
binomial_power_prior_log_marginal.RdUp to a constant that does not depend on the power parameter. The source log likelihoods are shifted to a maximum of zero; the shift multiplies the numerator and Z_S(gamma) alike, so it cancels.
Usage
binomial_power_prior_log_marginal(
terms,
power_parameter,
bilinear = binomial_power_prior_bilinear(terms)
)Arguments
- terms
Output of
binomial_power_prior_target_terms().- power_parameter
Power parameters in \([0, 1]\).