Generate a forest plot for bayesian metrics
Source:R/plot_methods_comparison_forestplot.R
forest_plot_bayesian.RdThis function generates a forest plot based on the provided results dataframe, selected case study, and selected target sample size per arm.