This function generates a forest plot based on the provided results dataframe, selected case study, and selected target sample size per arm.
This function generates a forest plot based on the provided results dataframe, selected case study, and selected target sample size per arm.