Calculate the precision-based Effective Sample Size (ESS) for a Gaussian mixture.
Source:R/analysis_prior_ess_estimation.R
gaussian_mix_precision_ess.RdThis function calculates the precision-based ESS for a Gaussian mixture distribution. It takes a mixture object and an optional prior reference scale as input and returns the ESS.