Normalises the density by the trapezoidal rule and accumulates it into the distribution function, from which the moments, quantiles and draws are read. Between grid points the density and the distribution function are interpolated linearly.
Normalises the density by the trapezoidal rule and accumulates it into the distribution function, from which the moments, quantiles and draws are read. Between grid points the density and the distribution function are interpolated linearly.