The design a time-to-event case study is primarily simulated under
Source:R/simulation_scenarios.R
is_primary_time_to_event_design.RdNo control-arm heterogeneity, no loss to follow-up, exponential event times and proportional hazards (no delay before the treatment effect). It is the design a configuration that does not mention the sensitivity axes produces, and the one the whole scenario grid is simulated at.
Usage
is_primary_time_to_event_design(
control_drift,
dropout_probability,
event_time_distribution,
treatment_delay = 0
)