R/simulation_data.R
negative_binomial_regression.Rd
This function estimates the rate parameter of an intercept-only negative binomial model and its standard error.
negative_binomial_regression(input_data)
The data for which the rate parameter and standard error need to be estimated.
A list containing the rate estimate, standard error of the rate estimate, and standard error of the log(rate) estimate.