Calibrate the KL normalized power prior to a design
Source:R/npp_kl_calibration.R
npp_kl_calibrate_design.RdThe expected target standard error is the one the design
implies, from npp_kl_expected_target_se(). It is not the standard error
of any replicate: those vary around this one, and using them would make
the prior a function of the data it is supposed to be a prior for.
Arguments
- source
The source data, with
treatment_effect_estimateandstandard_error.- target_data
Target study data for the scenario.
- theta_0
Boundary of the null hypothesis space.
- settings
Output of
npp_kl_settings().
Value
The output of calibrate_npp_kl().