Criterion settings of the KL-calibrated normalized power prior
Source:R/npp_kl_calibration.R
npp_kl_settings.RdRead from the method parameters, with the defaults of
calibrate_npp_kl(). Shared by GaussianNPP_KL and BinomialNPP_KL.
R/npp_kl_calibration.R
npp_kl_settings.RdRead from the method parameters, with the defaults of
calibrate_npp_kl(). Shared by GaussianNPP_KL and BinomialNPP_KL.