Calculate the probability of false positive
Source:R/analysis_bayesian_ocs.R
preposterior_proba_FP_MC.RdThis function calculates the probability of false positive based on the conditional probability of success, design prior samples, theta_0, and null space.
Usage
preposterior_proba_FP_MC(
conditional_proba_success,
design_prior_samples,
theta_0,
null_space
)