Calculate the success rate in the target study arm from the drift on the log odds ratio scale
Source:R/simulation_data.R
rate_from_drift_logOR.RdThis function calculates the success rate in the target study arm based on the drift (defined on the log scale) and the success rate in the arm of interest in the source study.