Calculate the rate in the target study arm from the drift on the log relative risk scale
Source:R/simulation_data.R
rate_from_drift_logRR.RdThis function calculates the rate in the target study arm based on the drift (defined on the log scale) and the rate in the arm of interest in the source study.