Sample aggregate normal data based on the mean and variance
Source:R/simulation_data.R
sample_aggregate_normal_data.RdThis function samples aggregate normal data based on the mean and variance.
R/simulation_data.R
sample_aggregate_normal_data.RdThis function samples aggregate normal data based on the mean and variance.