Only numbers introduced by "=" count. A notation such as the initial prior's carries a digit of its own (pi nought) that has nothing to do with the value the parameter took.
Only numbers introduced by "=" count. A notation such as the initial prior's carries a digit of its own (pi nought) that has nothing to do with the value the parameter took.