Generate tables for methods operating characteristics
Source:R/table_bayesian_operating_characteristics.R
table_bayesian_ocs.RdThis function creates tables for various Bayesian operating characteristics across different case studies and methods.
Usage
table_bayesian_ocs(
results_metrics_df,
metrics,
source_denominator_change_factor = 1,
target_to_source_std_ratio = 1
)Arguments
- results_metrics_df
A data frame containing the results and metrics.
- metrics
A vector of metric names to include in the tables.
- source_denominator_change_factor
The source denominator change factor of the scenario to keep.
- target_to_source_std_ratio
Ratio between the target and source studies sampling standard deviation.