Generate a table of hyperparameters estimated using Empirical Bayes vs drift
Source:R/table_empirical_bayes_hyperparameters_vs_scenario.R
table_empirical_bayes_hyperparameters_vs_drift.RdGenerate a table of hyperparameters estimated using Empirical Bayes vs drift
Usage
table_empirical_bayes_hyperparameters_vs_drift(
results_metrics_df,
method,
case_study,
control_drift,
xvars,
source_denominator_change_factor,
target_to_source_std_ratio,
parameters_combinations
)Arguments
- results_metrics_df
A data frame containing the results metrics.
- method
The method to filter the results by.
- case_study
The case study to filter the results by.
- control_drift
A logical value indicating whether to control for drift.
- xvars
A list containing the x-variable configurations.
- source_denominator_change_factor
The source denominator change factor of the scenario to keep.
- target_to_source_std_ratio
Ratio between the target and source studies sampling standard deviation.
- parameters_combinations
The combinations of parameters to filter the results by