How many time-to-event design axes are off their primary value
Source:R/simulation_scenarios.R
time_to_event_axes_off_primary.RdA sensitivity analysis that varies one axis at a time only needs the designs for which this is at most one; crossing the axes simulates every combination of them as well.
Usage
time_to_event_axes_off_primary(
control_drift,
dropout_probability,
event_time_distribution,
treatment_delay = 0
)